summaryrefslogtreecommitdiffstats
path: root/chrome/installer
diff options
context:
space:
mode:
authorgwilson@google.com <gwilson@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-05 19:36:03 +0000
committergwilson@google.com <gwilson@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-05 19:36:03 +0000
commit27845cac2c3443eca508003c3951739e88ae8f24 (patch)
treed772e3f622144f044b3b45542fc8ebc365c193a9 /chrome/installer
parentd604e96bed6afbdac45ed4d4318aab7bf693bd0b (diff)
downloadchromium_src-27845cac2c3443eca508003c3951739e88ae8f24.zip
chromium_src-27845cac2c3443eca508003c3951739e88ae8f24.tar.gz
chromium_src-27845cac2c3443eca508003c3951739e88ae8f24.tar.bz2
Change "client" parameter in RLZ ping to "referral"
to match Omaha's changes. BUG=1520348 Review URL: http://codereview.chromium.org/12975 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6440 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/installer')
-rw-r--r--chrome/installer/util/google_update_constants.cc2
-rw-r--r--chrome/installer/util/google_update_constants.h2
-rw-r--r--chrome/installer/util/google_update_settings.cc4
-rw-r--r--chrome/installer/util/google_update_settings.h4
4 files changed, 6 insertions, 6 deletions
diff --git a/chrome/installer/util/google_update_constants.cc b/chrome/installer/util/google_update_constants.cc
index 860229a..fc2dbc7 100644
--- a/chrome/installer/util/google_update_constants.cc
+++ b/chrome/installer/util/google_update_constants.cc
@@ -23,7 +23,7 @@ const wchar_t kRegRenameCmdField[] = L"cmd";
const wchar_t kRegRLZBrandField[] = L"brand";
const wchar_t kRegUsageStatsField[] = L"usagestats";
const wchar_t kRegVersionField[] = L"pv";
-const wchar_t kRegClientField[] = L"client";
+const wchar_t kRegReferralField[] = L"referral";
const wchar_t kEnvProductVersionKey[] = L"CHROME_VERSION";
} // namespace installer
diff --git a/chrome/installer/util/google_update_constants.h b/chrome/installer/util/google_update_constants.h
index bd225a8..66b1efe 100644
--- a/chrome/installer/util/google_update_constants.h
+++ b/chrome/installer/util/google_update_constants.h
@@ -28,7 +28,7 @@ extern const wchar_t kRegRenameCmdField[];
extern const wchar_t kRegRLZBrandField[];
extern const wchar_t kRegUsageStatsField[];
extern const wchar_t kRegVersionField[];
-extern const wchar_t kRegClientField[];
+extern const wchar_t kRegReferralField[];
extern const wchar_t kEnvProductVersionKey[];
} // namespace google_update
diff --git a/chrome/installer/util/google_update_settings.cc b/chrome/installer/util/google_update_settings.cc
index 57b20cb..8168be2 100644
--- a/chrome/installer/util/google_update_settings.cc
+++ b/chrome/installer/util/google_update_settings.cc
@@ -59,6 +59,6 @@ bool GoogleUpdateSettings::GetBrand(std::wstring* brand) {
return ReadGoogleUpdateStrKey(google_update::kRegRLZBrandField, brand);
}
-bool GoogleUpdateSettings::GetClient(std::wstring* client) {
- return ReadGoogleUpdateStrKey(google_update::kRegClientField, client);
+bool GoogleUpdateSettings::GetReferral(std::wstring* referral) {
+ return ReadGoogleUpdateStrKey(google_update::kRegReferralField, referral);
}
diff --git a/chrome/installer/util/google_update_settings.h b/chrome/installer/util/google_update_settings.h
index caa75b1..d5c6876 100644
--- a/chrome/installer/util/google_update_settings.h
+++ b/chrome/installer/util/google_update_settings.h
@@ -36,9 +36,9 @@ class GoogleUpdateSettings {
// assigned to a partner. Returns false if the information is not available.
static bool GetBrand(std::wstring* brand);
// Returns in 'client' the RLZ client id available for some distribution
// partners. This value does not exist for most chrome or chromium installs.
- static bool GetClient(std::wstring* client);
+ static bool GetReferral(std::wstring* referral);
private:
DISALLOW_IMPLICIT_CONSTRUCTORS(GoogleUpdateSettings);
@@ -36,9 +36,9 @@ class GoogleUpdateSettings {
// assigned to a partner. Returns false if the information is not available.
static bool GetBrand(std::wstring* brand);
- // Returns in 'client' the RLZ client id available for some distribution
+ // Returns in 'client' the RLZ referral available for some distribution
// partners. This value does not exist for most chrome or chromium installs.